@@ -9,7 +9,6 @@ from psycopg2 import connect, sql
 from fhir_cli import (
     CONNECT_CONFIG_TEMPLATE,
     CONNECT_URL,
-    CREATE_FDW_TEMPLATE,
     DBT_INIT_DB_TEMPLATE,
     DBT_META_TABLE,
     DBT_SCHEMA,
@@ -166,9 +165,8 @@ class Admin:
         )
         conn.autocommit = True
 
-        stmt = JINJA_ENV.get_template(CREATE_FDW_TEMPLATE).render(
+        stmt = JINJA_ENV.get_template(f"{SOURCE_TYPE}_fdw.sql.j2").render(
             source_db=SOURCE_DB,
-            source_type=SOURCE_TYPE,
             source_host=SOURCE_HOST,
             source_port=SOURCE_PORT,
             source_user=SOURCE_USER,
